@@ -108,7 +108,7 @@ class TestLocalFileProcessesAdapter(TestCase):
         custom_read_function.assert_called_once_with(test.path)
         self.assertEqual(out_come, data_output)
 
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.create_directory_if_not_exists")
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter._create_directory_if_not_exists")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.local_file_object")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.__init__")
     def test_write_file(self, mock_init, mock_local_file_object, mock_create_dir):
@@ -121,7 +121,7 @@ class TestLocalFileProcessesAdapter(TestCase):
         mock_create_dir.assert_called_once()
         mock_local_file_object.return_value.write.assert_called_once_with(data=mock_data)
 
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.create_directory_if_not_exists")
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter._create_directory_if_not_exists")
     @patch("monolith_filemanager.adapters.local_file_processes.open")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.__init__")
     def test_write_raw_file(self, mock_init, mock_open, mock_create_dir):
@@ -167,17 +167,22 @@ class TestLocalFileProcessesAdapter(TestCase):
         mock_check.assert_called_once_with(path=test.path)
         mock_os.remove.assert_called_once_with(test.path)
 
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.create_directory_if_not_exists")
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.delete_file")
+    def test_delete_folder(self, mock_delete_file):
+        mock_delete_file.return_value = None
+        self.test_folder.delete_folder()
+        mock_delete_file.assert_called_once_with(path=self.test_folder.path)
+
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter._create_directory_if_not_exists")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.increment_files")
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.exists")
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.check_name_taken")
-    @patch("monolith_filemanager.adapters.local_file_processes.os.walk")
+    @patch("monolith_filemanager.adapters.local_file_processes.os.path.isfile")
+    @patch("monolith_filemanager.adapters.local_file_processes.os.path.isdir")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.__init__")
-    def test_write_stream(self, mock_init, mock_walk, mock_check_name_taken, mock_exists, mock_increment_files, mock_create_dir):
+    def test_write_stream(self, mock_init, mock_os_path_isdir, mock_os_path_isfile, mock_increment_files,
+                          mock_create_dir):
         # test if name taken
         mock_init.return_value = None
-        mock_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        mock_check_name_taken.return_value = True
+        mock_os_path_isdir.return_value = True
         test = LocalFileProcessesAdapter(file_path="test path", caching=MagicMock())
         test.path = "mock/path/folder/file.txt"
         mock_stream = MagicMock()
@@ -186,22 +191,18 @@ class TestLocalFileProcessesAdapter(TestCase):
             test.write_stream(stream=mock_stream)
 
         # test file exists so increment
-        mock_walk.reset_mock()
-        mock_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        mock_check_name_taken.return_value = False
-        mock_exists.return_value = True
+        mock_os_path_isdir.return_value = False
+        mock_os_path_isfile.return_value = True
         self.assertEqual("file.txt", test.write_stream(stream=mock_stream))
         mock_increment_files.assert_called_once_with()
         mock_create_dir.assert_called_once()
         mock_stream.save.assert_called_once_with(test.path)
 
         # test file does not exist, no increment
-        mock_walk.reset_mock()
+        mock_os_path_isdir.return_value = False
+        mock_os_path_isfile.return_value = False
         mock_create_dir.reset_mock()
         mock_stream.reset_mock()
-        mock_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        mock_check_name_taken.return_value = False
-        mock_exists.return_value = False
         self.assertEqual("file.txt", test.write_stream(stream=mock_stream))
         mock_create_dir.assert_called_once()
         mock_stream.save.assert_called_once_with(test.path)
@@ -222,39 +223,35 @@ class TestLocalFileProcessesAdapter(TestCase):
         self.assertEqual("mock/path/folder/file 3.txt", test.path)
 
     @patch("monolith_filemanager.adapters.local_file_processes.os.makedirs")
-    @patch("monolith_filemanager.adapters.local_file_processes.os.path.exists")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.increment_folders")
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.check_name_taken")
-    @patch("monolith_filemanager.adapters.local_file_processes.os.walk")
+    @patch("monolith_filemanager.adapters.local_file_processes.os.path.isdir")
+    @patch("monolith_filemanager.adapters.local_file_processes.os.path.isfile")
     @patch("monolith_filemanager.adapters.local_file_processes.os.path.dirname")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.__init__")
-    def test_create_directory_if_not_exists(self, mock_init, mock_os_path_dirname, mock_os_walk, mock_check_name_taken,
-                                            mock_increment_folders, mock_os_path_exists, mock_os_makedirs):
+    def test_create_directory_if_not_exists(self, mock_init, mock_os_path_dirname, mock_os_path_is_file,
+                                            mock_os_path_is_dir, mock_increment_folders, mock_os_makedirs):
         mock_init.return_value = None
         test = LocalFileProcessesAdapter(file_path="test path", caching=MagicMock())
         test.path = "mock/pardir/folder/file"
         # test if name taken
         mock_os_path_dirname.side_effect = ["mock/pardir/folder", "mock/pardir"]
-        mock_os_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        mock_check_name_taken.return_value = True
+        mock_os_path_is_file.return_value = True
         with self.assertRaises(LocalProcessesAdapterError):
             test.create_directory_if_not_exists()
 
         # test if doesn't exist
-        mock_check_name_taken.return_value = False
-        mock_os_path_exists.return_value = False
+        mock_os_path_is_file.return_value = False
+        mock_os_path_is_dir.return_value = False
         mock_os_path_dirname.side_effect = ["mock/pardir/folder", "mock/pardir"]
-        mock_os_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
         self.assertEqual("folder", test.create_directory_if_not_exists())
         mock_os_makedirs.assert_called_once_with("mock/pardir/folder")
 
         # test if already exists
-        mock_check_name_taken.return_value = False
-        mock_os_path_exists.return_value = True
+        mock_os_path_is_file.return_value = False
+        mock_os_path_is_dir.return_value = True
         mock_increment_folders.return_value = "folder 2"
         mock_os_path_dirname.side_effect = ["mock/pardir/folder", "mock/pardir"]
-        mock_os_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        self.assertEqual("folder 2", test.create_directory_if_not_exists(increment=True))
+        self.assertEqual("folder 2", test.create_directory_if_not_exists())
         mock_increment_folders.assert_called_once_with(dirname="mock/pardir/folder")
 
     @patch("monolith_filemanager.adapters.local_file_processes.os.makedirs")
@@ -316,40 +313,82 @@ class TestLocalFileProcessesAdapter(TestCase):
                                              call(path=test.path + mock_paths[1])]
 
     @patch("monolith_filemanager.adapters.local_file_processes.os.rename")
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.check_name_taken")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.exists")
-    @patch("monolith_filemanager.adapters.local_file_processes.os.walk")
     @patch("monolith_filemanager.adapters.local_file_processes.os.path.splitext")
     @patch("monolith_filemanager.adapters.local_file_processes.os.path.dirname")
-    def test_rename_file(self, mock_os_dirname, mock_os_splitext, mock_os_walk, mock_exists, mock_check_name_taken,
-                         mock_os_rename):
+    def test_rename_file(self, mock_os_dirname, mock_os_splitext, mock_exists, mock_os_rename):
         new_name = "new_file"
         mock_os_dirname.return_value = "/".join(self.test_file.path.split("/")[:-1])
         mock_os_splitext.return_value = ["mock/folder/test", ".xlsx"]
-        mock_os_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        mock_exists.return_value = True
-        mock_check_name_taken.return_value = False
+        mock_exists.side_effect = [True, False]
 
         new_path = "/".join(self.test_file.path.split("/")[:-1]) + f"/{new_name}" + mock_os_splitext.return_value[-1]
         self.test_file.rename_file(new_name=new_name)
         mock_os_rename.assert_called_once_with(self.test_file.path, new_path)
 
     @patch("monolith_filemanager.adapters.local_file_processes.os.rename")
-    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.check_name_taken")
     @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.exists")
     @patch("monolith_filemanager.adapters.local_file_processes.os.walk")
     @patch("monolith_filemanager.adapters.local_file_processes.os.path.dirname")
-    def test_rename_folder(self, mock_os_dirname, mock_os_walk, mock_exists, mock_check_name, mock_rename):
+    def test_rename_folder(self, mock_os_dirname, mock_os_walk, mock_exists, mock_rename):
         new_name = "new_folder"
         mock_os_dirname.return_value = "/".join(self.test_folder.path.split("/")[:-1])
         mock_os_walk.return_value = iter([["mock/root", ["dir1", "dir2"], ["file1.txt"]]])
-        mock_exists.return_value = True
-        mock_check_name.return_value = False
+        mock_exists.side_effect = [True, False]
 
         new_path = "/".join(self.test_folder.path.split("/")[:-1]) + f"/{new_name}"
         self.test_folder.rename_file(new_name=new_name)
         mock_rename.assert_called_once_with(self.test_folder.path, new_path)
 
+    @patch("monolith_filemanager.adapters.local_file_processes.os.rename")
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.exists")
+    def test__move(self, mock_exists, mock_os_rename):
+        mock_exists.return_value = False
+        mock_os_rename.return_value = None
+        mock_new_path = MagicMock()
+        self.test_folder._move(mock_new_path)
+        mock_os_rename.assert_called_once_with(self.test_folder.path, mock_new_path)
+
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter._move")
+    @patch("monolith_filemanager.adapters.local_file_processes.FilePath")
+    def test_move_file(self, mock_file_path, mock_move):
+        mock_file_path.return_value = MagicMock()
+        mock_move.return_value = None
+        mock_destination_folder = "mock/destination/folder"
+        self.test_file.move_file(f"{mock_destination_folder}")
+        mock_file_path.assert_called_once_with(f"{mock_destination_folder}/{self.test_file.path.split('/')[-1]}")
+        mock_move.assert_called_once_with(new_path=mock_file_path.return_value)
+
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter._move")
+    @patch("monolith_filemanager.adapters.local_file_processes.FilePath")
+    def test_move_folder(self, mock_file_path, mock_move):
+        mock_file_path.return_value = MagicMock()
+        mock_move.return_value = None
+        mock_destination_folder = "mock/destination/folder"
+        self.test_folder.move_file(f"{mock_destination_folder}")
+        mock_file_path.assert_called_once_with(f"{mock_destination_folder}/{self.test_folder.path.split('/')[-1]}")
+        mock_move.assert_called_once_with(new_path=mock_file_path.return_value)
+
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.move_folder")
+    @patch("monolith_filemanager.adapters.local_file_processes.LocalFileProcessesAdapter.move_file")
+    @patch("monolith_filemanager.adapters.local_file_processes.os.path.isdir")
+    @patch("monolith_filemanager.adapters.local_file_processes.os.path.isfile")
+    @patch("monolith_filemanager.adapters.local_file_processes.FilePath")
+    def test_batch_move(self, mock_filepath, mock_os_isfile, mock_os_isdir, mock_move_file, mock_move_folder):
+        mock_paths = ["test.xlsx", "test_folder"]
+        mock_destination_folder = "mock/destination/folder"
+        mock_filepath.side_effect = [MagicMock(), MagicMock()]
+        mock_os_isfile.side_effect = [True, False]
+        mock_os_isdir.side_effect = [False, True]
+        mock_move_file.return_value = None
+        mock_move_folder.return_value = None
+
+        self.test_folder.batch_move(paths=mock_paths, destination_folder=mock_destination_folder)
+        mock_filepath.assert_has_calls([call(f"{self.test_folder.path}/{mock_paths[0]}"),
+                                        call(f"{self.test_folder.path}/{mock_paths[1]}")])
+        mock_move_file.assert_called_once_with(destination_folder=mock_destination_folder)
+        mock_move_folder.assert_called_once_with(destination_folder=mock_destination_folder)
+
 
 if __name__ == "__main__":
     main()
